package org.greenstone.gatherer.gui;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;
import org.greenstone.gatherer.gui.border.TitledBorder;
/** Gatherers own version of the javax.swing.BorderFactory which has two major differences: firstly the titled borders returned are org.greenstone.gatherer.gui.border.TitledBorders which are aware who their parents are and are -not- ever shared. The second difference is that I haven't been so much of a biarch as to use a private contructor so as prevent any other programmer in the world from extending my class. Jaded? Me? Nah.
 * @author John Thompson, Digital Library, University of Waikato.
 * @version 2.3
 */
public class BorderFactory {
    /** Creates a beveled border of the specified type, using brighter shades of the component's current background color for highlighting, and darker shading for shadows. */
    static public Border createBevelBorder(int type) {
	return javax.swing.BorderFactory.createBevelBorder(type);
    }
    /** Creates a beveled border of the specified type, using the specified highlighting and shadowing. */
    static public Border createBevelBorder(int type, Color highlight, Color shadow) {
	return javax.swing.BorderFactory.createBevelBorder(type, highlight, shadow);
    }
    /** Creates a beveled border of the specified type, using the specified colors for the inner and outer highlight and shadow areas. */
    static public Border createBevelBorder(int type, Color highlightOuter, Color highlightInner, Color shadowOuter, Color shadowInner) {
	return javax.swing.BorderFactory.createBevelBorder(type, highlightOuter, highlightInner, shadowOuter, shadowInner);
    }
    /** Creates a compound border with a null inside edge and a null outside edge. */
    static public CompoundBorder createCompoundBorder() {
	return javax.swing.BorderFactory.createCompoundBorder();
    }
    /** Creates a compound border specifying the border objects to use for the outside and inside edges. */
    static public CompoundBorder createCompoundBorder(Border outsideBorder, Border insideBorder) {
	return javax.swing.BorderFactory.createCompoundBorder(outsideBorder, insideBorder);
    }
    /** Creates an empty border that takes up no space. */
    static public Border createEmptyBorder() {
	return javax.swing.BorderFactory.createEmptyBorder();
    }
    /** Creates an empty border that takes up space but which does no drawing, specifying the width of the top, left, bottom, and right sides. */
    static public Border createEmptyBorder(int top, int left, int bottom, int right) {
	return javax.swing.BorderFactory.createEmptyBorder(top, left, bottom, right);
    }
    /** Creates a border with an "etched" look using the component's current background color for highlighting and shading. */
    static public Border createEtchedBorder() {
	return javax.swing.BorderFactory.createEtchedBorder();
    }
    /** Creates a border with an "etched" look using the specified highlighting and shading colors. */
    static public Border createEtchedBorder(Color highlight, Color shadow) {
	return javax.swing.BorderFactory.createEtchedBorder(highlight, shadow);
    }
    /** Creates a border with an "etched" look using the component's current background color for highlighting and shading. */
    static public Border createEtchedBorder(int type) {
	return javax.swing.BorderFactory.createEtchedBorder(type);
    }
    /** Creates a border with an "etched" look using the specified highlighting and shading colors. */
    static public Border createEtchedBorder(int type, Color highlight, Color shadow) {
	return javax.swing.BorderFactory.createEtchedBorder(type, highlight, shadow);
    }
    /** Creates a line border withe the specified color. */
    static public Border createLineBorder(Color color) {
	return javax.swing.BorderFactory.createLineBorder(color);
    }
    /** Creates a line border with the specified color and width. */
    static public Border createLineBorder(Color color, int thickness) {
	return javax.swing.BorderFactory.createLineBorder(color, thickness);
    }
    /** Creates a border with a lowered beveled edge, using brighter shades of the component's current background color for highlighting, and darker shading for shadows. */
    static public Border createLoweredBevelBorder() {
	return javax.swing.BorderFactory.createLoweredBevelBorder();
    }
    /** Creates a matte-look border using a solid color. */
    static public MatteBorder createMatteBorder(int top, int left, int bottom, int right, Color color) {
	return javax.swing.BorderFactory.createMatteBorder(top, left, bottom, right, color);
    }
    /** Creates a matte-look border that consists of multiple tiles of a specified icon. */
    static public MatteBorder createMatteBorder(int top, int left, int bottom, int right, Icon tileIcon) {
	return javax.swing.BorderFactory.createMatteBorder(top, left, bottom, right, tileIcon);
    }
    /** Creates a border with a raised beveled edge, using brighter shades of the component's current background color for highlighting, and darker shading for shadows. */
    static public Border createRaisedBevelBorder() {
	return javax.swing.BorderFactory.createRaisedBevelBorder();
    }
    /** Creates a new title border with an empty title specifying the border object, using the default text position (sitting on the top line) and default justification (leading) and using the default font, and text color. */
    static public org.greenstone.gatherer.gui.border.TitledBorder createTitledBorder(Border border) {
	return new org.greenstone.gatherer.gui.border.TitledBorder(border);
    }
    /** Adds a title to an existing border, specifying the text of the title, using the default positioning (sitting on the top line) and default justification (leading) and using the default font and text color determined by the current look and feel. */
    static public org.greenstone.gatherer.gui.border.TitledBorder createTitledBorder(Border border, String title) {
	return new org.greenstone.gatherer.gui.border.TitledBorder(border, title);
    }
    /** Adds a title to an existing border, specifying the text of the title along with its positioning, using the default font and text color determined by the current look and feel. */
    static public org.greenstone.gatherer.gui.border.TitledBorder createTitledBorder(Border border, String title, int justification, int position) {
	return new org.greenstone.gatherer.gui.border.TitledBorder(border, title, justification, position);
    }
    /** Adds a title to an existing border, specifying the text of the title along with its positioning and font, using the default text color determined by the current look and feel. */
    static public org.greenstone.gatherer.gui.border.TitledBorder createTitledBorder(Border border, String title, int justification, int position, Font font) {
	return new org.greenstone.gatherer.gui.border.TitledBorder(border, title, justification, position, font);
    }
    /** Adds a title to an existing border, specifying the text of the title along with its positioning, font, and color. */
    static public org.greenstone.gatherer.gui.border.TitledBorder createTitledBorder(Border border, String title, int justification, int position, Font font, Color color) {
	return new org.greenstone.gatherer.gui.border.TitledBorder(border, title, justification, position, font, color);
    }
    /** Creates a new title border specifying the text of the title, using the default border (etched), using the default text position (sitting on the top line) and default justification (leading) and using the default font and text color determined by the current look and feel. */
    static public org.greenstone.gatherer.gui.border.TitledBorder createTitledBorder(String title) {
	return new org.greenstone.gatherer.gui.border.TitledBorder(title);
    }
}
